.. meta::
   :description: Ironic administrator guide for managing OpenStack bare metal infrastructure. Operation, configuration, drivers, networking, and troubleshooting for production deployments.
   :keywords: ironic admin, bare metal administration, openstack infrastructure, ironic configuration, hardware drivers, network configuration, conductor management
   :author: OpenStack Ironic Team
   :robots: index, follow
   :audience: system administrators, cloud operators, infrastructure engineers

Administrator's Guide
=====================

If you are a system administrator running Ironic, this section contains
information that may help you understand how to operate and upgrade
the services.

.. toctree::
  :maxdepth: 3

  drivers
  features
  operation
  architecture
  availability-zones

.. toctree::
  :hidden:

  deploy-steps
  conductor-groups
  networking
  vxlan
  multitenancy
